@@ -5,7 +5,6 @@ import (
 	"encoding/json"
 	"fmt"
 	"log/slog"
-	"os"
 
 	"github.com/ubuntu/ubuntu-insights/insights/internal/collector"
 	"github.com/ubuntu/ubuntu-insights/insights/internal/consent"
@@ -37,11 +36,27 @@ type UploadFlags struct {
 	DryRun bool
 }
 
+// Collect errors.
+var (
+	// ErrDuplicateReport is returned by Collect when a report for the specified period already exists.
+	ErrDuplicateReport = collector.ErrDuplicateReport
+	// ErrSanitizeError is returned by Collect when the Config is not properly configured in an unrecoverable manner.
+	ErrSanitizeError = collector.ErrSanitizeError
+	// ErrSourceMetricsError is returned by Collect when the source metrics could not be loaded or parsed.
+	ErrSourceMetricsError = collector.ErrSourceMetricsError
+)
+
+// Upload errors.
+var (
+	// ErrSendFailure is returned by Upload when a report fails to be sent to the server, either due to a network error or a non-200 status code.
+	ErrSendFailure = uploader.ErrSendFailure
+)
+
 // Resolve returns a copy of the config with default values filled in where necessary.
 //
 // If ConsentDir is not set, a default path will be used.
 // If InsightsDir is not set, a default path will be used.
-// If Logger is not set, a default logger will be created.
+// If Logger is not set, the global default slog Logger will be used.
 func (c Config) Resolve() Config {
 	if c.ConsentDir == "" {
 		c.ConsentDir = constants.DefaultConfigPath
@@ -51,7 +66,7 @@ func (c Config) Resolve() Config {
 	}
 
 	if c.Logger == nil {
-		c.Logger = slog.New(slog.NewTextHandler(os.Stdout, &slog.HandlerOptions{Level: slog.LevelInfo}))
+		c.Logger = slog.Default()
 	}
 	return c
 }
@@ -87,7 +102,7 @@ func (c Config) Collect(source string, flags CollectFlags) ([]byte, error) {
 	}
 
 	insights, err := col.Compile(flags.Force)
-	if err != nil {
+	if err != nil { // Errors may need to be exposed for caller correction.
 		return nil, err
 	}
 
